@@ -7,6 +7,7 @@ test_that("Dyad-year additions do not create duplicates", {
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_contiguity()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_capital_distance()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_cow_majors()))
+  expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_cow_trade()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_democracy()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_gwcode_to_cow()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_mids()))
@@ -20,6 +21,7 @@ test_that("State-year additions do not create duplicates", {
   expect_equal(nrow(create_stateyears()), nrow(create_stateyears() %>% add_contiguity()))
   expect_equal(nrow(create_stateyears()), nrow(create_stateyears() %>% add_capital_distance()))
   expect_equal(nrow(create_stateyears()), nrow(create_stateyears() %>% add_cow_majors()))
+  expect_equal(nrow(create_stateyears()), nrow(create_stateyears() %>% add_cow_trade()))
   expect_equal(nrow(create_stateyears()), nrow(create_stateyears() %>% add_democracy()))
   expect_equal(nrow(create_stateyears()), nrow(create_stateyears() %>% add_gwcode_to_cow()))
   expect_equal(nrow(create_stateyears()), nrow(create_stateyears() %>% add_nmc()))
